KIN
===

KIN is a tool to check whether your project.pbxproj file is correct

Usage
-----

::

  Usage: kin [project.pbxproj]

  Verifies the correctness of your project.pbxproj file.
  When called with no arguments, Kin will try to find a project.pbxproj file in the current project.
